import React, { useState } from 'react';
import { Col, Row } from 'react-bootstrap';
import { GrAdd, GrSubtract  } from 'react-icons/gr';

interface CollapsibleBoxProps {
  title: string;
  children: React.ReactNode;
  startCollapsed?: boolean;
}

const CollapsibleBox: React.FC<CollapsibleBoxProps> = ({ title, children, startCollapsed }) => {
  const [isCollapsed, setIsCollapsed] = useState(!!startCollapsed);

  return (
    <div className='collapsible-box'>
      <Row>
        <Col>
          <h1 className="bold-caps-16pt dark-teal">{title}</h1>
        </Col>
        <Col align="right">
        <button className="expand-collapse-btn" onClick={() => setIsCollapsed(!isCollapsed)}>
            {isCollapsed ? <GrAdd/> : <GrSubtract />}
        </button>
        </Col>
      </Row>



      {!isCollapsed && <div className='collapsible-content'>
        {children}
      </div>}

    </div>
  );
};

export default CollapsibleBox;
