import React, { ReactElement, useEffect, useMemo, useState } from 'react';
import { Row } from "react-bootstrap";

import { Budget, FilterSelection } from "../Schema";
import { createBudgetDataset, getYearsAndNrens, loadDataWithFilterNrenSelectionFallback } from "../helpers/dataconversion";
import DataPage from '../components/DataPage';
import Filter from "../components/graphing/Filter";
import LineGraph from "../components/graphing/LineGraph";
import { Sections } from '../helpers/constants';

interface inputProps {
    filterSelection: FilterSelection
    setFilterSelection: React.Dispatch<React.SetStateAction<FilterSelection>>
}

function BudgetPage({ filterSelection, setFilterSelection }: inputProps): ReactElement {

    const [budgetResponse, setBudget] = useState<Budget[]>([]);

    const { nrens } = useMemo(
        () => getYearsAndNrens(budgetResponse),
        [budgetResponse]
    );

    const budgetData = createBudgetDataset(budgetResponse);

    budgetData.datasets.forEach(dataset => {
        dataset.hidden = !filterSelection.selectedNrens.includes(dataset.label);
    });

    useEffect(() => {
        loadDataWithFilterNrenSelectionFallback('/api/budget/', setBudget, setFilterSelection);
    }, [setFilterSelection]);

    const filterNode = <Filter
        filterOptions={{ availableYears: [], availableNrens: [...nrens.values()] }}
        filterSelection={filterSelection}
        setFilterSelection={setFilterSelection}
    />

    return (
        <DataPage title="Budgets" category={Sections.Organisation} filter={filterNode}>
            <>
                <Row>
                    <LineGraph data={budgetData} />
                </Row>
            </>
        </DataPage>
    );
}

export default BudgetPage;
