import React, { useEffect, useMemo, useState } from 'react';
import { Table } from "react-bootstrap";

import { ECProject, FilterSelection } from "../Schema";
import { createECProjectsDataLookup, getYearsAndNrens, loadDataWithFilterSelectionFallback } from '../helpers/dataconversion';
import DataPage from '../components/DataPage';
import Filter from "../components/graphing/Filter"
import { Sections } from '../helpers/constants';


interface inputProps {
    filterSelection: FilterSelection
    setFilterSelection: React.Dispatch<React.SetStateAction<FilterSelection>>
}

function getJSXFromMap(data: Map<string, Map<number, ECProject[]>>) {
    return Array.from(data.entries()).map(([nren, nrenMap]) => {
        return Array.from(nrenMap.entries()).map(([year, projects], yearIndex) => (
            <tr key={nren + year} className='dotted-border'>
                <td className='pt-3 nren-column text-nowrap'>{yearIndex == 0 && nren}</td>
                <td className='pt-3 year-column'>{year}</td>
                <td className='pt-3 blue-column'>
                    <ul>
                        {projects.map(project => (
                            <li key={project.project}>{project.project}</li>
                        ))}
                    </ul>
                </td>
            </tr>
        ))
    })
}

function ECProjects({ filterSelection, setFilterSelection }: inputProps) {
    const [projectData, setProjectData] = useState<ECProject[]>([]);

    const { years, nrens } = useMemo(
        () => getYearsAndNrens(projectData),
        [projectData]
    );

    const selectedData = (projectData).filter(project =>
        filterSelection.selectedYears.includes(project.year) && filterSelection.selectedNrens.includes(project.nren)
    );
    const projectDataByYear = createECProjectsDataLookup(selectedData);

    useEffect(() => {
        loadDataWithFilterSelectionFallback('/api/ec-project/', setProjectData, setFilterSelection);
    }, [setFilterSelection]);

    const filterNode = <Filter
        filterOptions={{ availableYears: [...years], availableNrens: [...nrens.values()] }}
        filterSelection={filterSelection}
        setFilterSelection={setFilterSelection}
    />

    return (
        <DataPage title="NREN Involvement in European Commission Projects" category={Sections.Organisation} filter={filterNode}>
            <Table borderless className='compendium-table'>
                <thead>
                    <tr>
                        <th className='nren-column'>NREN</th>
                        <th className='year-column'>Year</th>
                        <th className='blue-column'>EC Project Membership</th>
                    </tr>
                </thead>
                <tbody>
                    {getJSXFromMap(projectDataByYear)}
                </tbody>
            </Table>
        </DataPage>
    )
}
export default ECProjects;
